import requests

class API(object):
  def __init__(self, access_token):
    super(API, self).__init__()
    self.access_token = access_token

  def fetch_user(self):
    return self.__get_json('current_user')

  def fetch_campaign_and_patrons(self):
    return self.__get_json('current_user/campaigns?include=rewards,creator,goals,pledges')

  def __get_json(self, suffix):
    response = requests.get("https://api.patreon.com/oauth2/api/{}".format(suffix),
      headers={'Authorization': "Bearer {}".format(self.access_token)})
    return response.json()



import requests

class OAuth(object):
  def __init__(self, client_id, client_secret):
    super(OAuth, self).__init__()
    self.client_id = client_id
    self.client_secret = client_secret

  def get_tokens(self, code, redirect_uri):
    return self.__update_token({
        "grant_type": "authorization_code",
        "code": code,
        "client_id": self.client_id,
        "client_secret": self.client_secret,
        "redirect_uri": redirect_uri
    })

  def refresh_token(self, refresh_token, redirect_uri):
    return self.__update_token({
        "grant_type": "refresh_token",
        "refresh_token": refresh_token,
        "client_id": self.client_id,
        "client_secret": self.client_secret
    })

  def __update_token(self, params):
    response = requests.post("https://api.patreon.com/oauth2/token", params=params)
    return response.json()


from setuptools import setup

setup(name='patreon',
      version='0.0.5',
      description='Python library for interacting with the Patreon API. OAuth-centric for now.',
      url='http://github.com/Patreon/patreon-python',
      author='Patreon',
      author_email='david@patreon.com',
      license='MIT',
      packages=['patreon'],
      install_requires=[
          'requests',
      ],
      zip_safe=True)
